* figure7.do
* event-study estimates for NAEP scores by free lunch status
* 4th grade and 8th grade

global sub1 "math"
global sub2 "reading"

* 4th graders

foreach var in freelunch nolunch {
	foreach s in 1 2 {

		use data\naep\naep4, clear

		gen clustervar=statefip
		gen cvdf=50

		qui reg mean_`var' normyrl3p-normyrp6p i.year i.statefip if subject==`s', cluster(clustervar)
		cap drop coef* se* lower* upper*
		gen coef=0
		gen se=. 
		gen lower=.
		gen upper=.

		replace coef=_b[normyrl3p] if normyrgrp==-3.5
		replace se=_se[normyrl3p] if normyrgrp==-3.5

		replace coef=_b[normyrp0_1] if normyrgrp==.5
		replace se=_se[normyrp0_1] if normyrgrp==.5

		replace coef=_b[normyrp2_3] if normyrgrp==2.5
		replace se=_se[normyrp2_3] if normyrgrp==2.5

		replace coef=_b[normyrp4_5] if normyrgrp==4.5
		replace se=_se[normyrp4_5] if normyrgrp==4.5

		replace coef=_b[normyrp6p] if normyrgrp==6.5
		replace se=_se[normyrp6p] if normyrgrp==6.5

		replace lower=coef-se*invttail(cvdf,.05)
		replace upper=coef+se*invttail(cvdf,.05)

		cap drop tag	
		keep if normyear~=.
		egen tag=tag(normyrgrp)
		keep if tag
		keep normyrgrp coef lower upper
		save temp_`var'`s', replace

	}
}

global sub1 "math"
global sub2 "reading"

foreach s in 1 2 {
	use temp_freelunch`s', clear
	replace normyrgrp=normyrgrp-.1
	save, replace

	use temp_nolunch`s', clear
	replace normyrgrp=normyrgrp+.1
	foreach var in coef upper lower {
		ren `var' `var'2
		}
	save, replace

	use temp_freelunch`s'
	append using temp_nolunch`s'

	label var coef "Eligible for Free or Reduced-Price Lunch"
	label var coef2 "Not Eligible for Free or Reduced-Price Lunch"
	label var lower "90% CI"
	label var upper "90% CI"
	label var lower2 "90% CI"
	label var upper2 "90% CI"
	
	gr two (scatter coef normyrgrp, mcolor(green) lcolor(green) msym(O)) (rcap lower upper normyrgrp, lcolor(green) lpattern(solid) mcolor(green)) ///
	(scatter coef2 normyrgrp, mcolor(orange) lcolor(orange) msym(Oh)) (rcap lower2 upper2 normyrgrp, lcolor(orange) lpattern(dash) mcolor(orange)), yline(0, lcolor(black) lpat(dot)) ///
	xtick(-7.5(2)6.5) xlab(-7.5(2)6.5, labsize(medium)) legend(region(lcolor(none)) size(medsmall)) scheme(s1color) plotregion(lcolor(none)) ytick(-5(5)15) ylab(-5(5)15, labsize(medium)) ///
	yline(0, lcolor(black) lpat(dot)) xtitle("Cohort Relative to First Cohort with Universal Preschool (Midpoint of 2-Year Window)") saving(graphs\figure7_g4${sub`s'}, replace)
	gr export graphs\figure7_g4${sub`s'}.emf, as(wmf) replace
}

* 8th graders
foreach var in freelunch nolunch {
	foreach s in 1 2 {
		use data\naep\naep8, clear
		gen clustervar=statefip
		gen cvdf=50

		qui reg mean_`var' normyrl7p-normyrp4p i.year i.statefip if subject==`s', cluster(clustervar)
		cap drop coef* se* lower* upper*
		gen coef=0
		gen se=. 
		gen lower=.
		gen upper=.

		replace coef=_b[normyrl7p] if normyrgrp==-7.5
		replace se=_se[normyrl7p] if normyrgrp==-7.5

		replace coef=_b[normyrl5_6] if normyrgrp==-5.5
		replace se=_se[normyrl5_6] if normyrgrp==-5.5

		replace coef=_b[normyrl3_4] if normyrgrp==-3.5
		replace se=_se[normyrl3_4] if normyrgrp==-3.5

		replace coef=_b[normyrp0_1] if normyrgrp==.5
		replace se=_se[normyrp0_1] if normyrgrp==.5

		replace coef=_b[normyrp2_3] if normyrgrp==2.5
		replace se=_se[normyrp2_3] if normyrgrp==2.5

		replace coef=_b[normyrp4p] if normyrgrp==4.5
		replace se=_se[normyrp4p] if normyrgrp==4.5

		replace lower=coef-se*invttail(cvdf,.05) 
		replace upper=coef+se*invttail(cvdf,.05) 

		cap drop tag	
		keep if normyear~=.
		egen tag=tag(normyrgrp)
		keep if tag
		keep normyrgrp coef lower upper
		save temp_`var'`s', replace

	}
}

foreach s in 1 2 {
	use temp_freelunch`s', clear
	replace normyrgrp=normyrgrp-.1
	save, replace

	use temp_nolunch`s', clear
	replace normyrgrp=normyrgrp+.1
	foreach var in coef upper lower {
		ren `var' `var'2
		}
	save, replace

	use temp_freelunch`s'
	append using temp_nolunch`s'

	label var coef "Eligible for Free or Reduced-Price Lunch"
	label var coef2 "Not Eligible for Free or Reduced-Price Lunch"
	label var lower "90% CI"
	label var upper "90% CI"
	label var lower2 "90% CI"
	label var upper2 "90% CI"
	
	gr two (scatter coef normyrgrp, mcolor(green) msym(O)) (rcap lower upper normyrgrp, lcolor(green) lpattern(solid) mcolor(blue)) ///
	(scatter coef2 normyrgrp, mcolor(orange) msym(Oh)) (rcap lower2 upper2 normyrgrp, lcolor(orange) lpattern(dash) mcolor(orange)), yline(0, lcolor(black) lpat(dot)) ///
	xtick(-7.5(2)6.5) xlab(-7.5(2)6.5, labsize(medium)) legend(region(lcolor(none)) size(medsmall)) scheme(s1color) plotregion(lcolor(none)) ytick(-5(5)15) ylab(-5(5)15, labsize(medium)) ///
	yline(0, lcolor(black) lpat(dot)) xtitle("Cohort Relative to First Cohort with Universal Preschool (Midpoint of 2-Year Window)") saving(graphs\figure7_g8${sub`s'}, replace)
	gr export graphs\figure7_g8${sub`s'}.emf, as(wmf) replace
}

foreach g in freelunch nolunch {
	foreach s in 1 2 {
		erase temp_`g'`s'.dta
	}
}
