* apptab_b3.do

*******************************************
* October CPS
* DD estimates for preschool enrollment 
* Comparison group: rest of U.S.
* Stratification variable: free/RP lunch
*******************************************

use data\octcps\octcps1977_2011-st-lunch, clear
keep if age==4
gen clustervar=statefip

* convert dependent variables to percentages
gen enrprepriv=enrpre-enrprepub
foreach var in enrpre enrprepub enrprepriv {
	replace `var'=`var'*100
	}
gen nolunch=1-lunch

cd outreg/appendixB

* DD estimates
foreach var in enrpre enrprepub enrprepriv {

	qui reg `var' post i.statefip i.year [aw=nobs] if nolunch==0, cluster(clustervar)
	outreg2 post using apptab_b3-`var'.xml, replace excel title("Table B-3: `var'") ctitle("F/RP Lunch Eligible", "Baseline")

	qui reg `var' post nonwhite female unemp i.statefip i.year [aw=nobs] if nolunch==0, cluster(clustervar)
	outreg2 post nonwhite female unemp using apptab_b3-`var'.xml, append excel title("Table B-3: `var'") ctitle("F/RP Lunch Eligible", "(1) + Demographic Controls and Unemployment")

	qui reg `var' post nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if nolunch==0, cluster(clustervar)
	outreg2 post nonwhite female unemp year_ok year_ga using apptab_b3-`var'.xml, append excel title("Table B-3: `var'") ctitle("F/RP Lunch Eligible", "(2) + OK and GA specific linear trends")

	qui reg `var' post i.statefip i.year [aw=nobs] if nolunch==1, cluster(clustervar)
	outreg2 post using apptab_b3-`var'.xml, append excel title("Table B-3: `var'") ctitle("Not F/RP Lunch Eligible", "Baseline")

	qui reg `var' post nonwhite female unemp i.statefip i.year [aw=nobs] if nolunch==1, cluster(clustervar)
	outreg2 post nonwhite female unemp using apptab_b3-`var'.xml, append excel title("Table B-3: `var'") ctitle("Not F/RP Lunch Eligible", "(1) + Demographic Controls and Unemployment")

	qui reg `var' post nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if nolunch==1, cluster(clustervar)
	outreg2 post nonwhite female unemp year_ok year_ga using apptab_b3-`var'.xml, append excel title("Table B-3: `var'") ctitle("Not F/RP Lunch Eligible", "(2) + OK and GA specific linear trends")

}

* Crowd-out estimates (IV)

qui xi: ivreg enrprepriv (enrprepub=post) i.statefip i.year [aw=nobs] if nolunch==0, cluster(clustervar)
outreg2 enrprepub using apptab_b3_iv.xml, replace excel title("Table B-3: Crowd-out ratio (ch. private given ch. public)") ctitle("F/RP Lunch Eligible", "Baseline")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp i.statefip i.year [aw=nobs] if nolunch==0, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp using apptab_b3_iv.xml, append excel title("Table B-3: Crowd-out ratio (ch. private given ch. public)") ctitle("F/RP Lunch Eligible", "(1) + Demographic Controls and Unemployment")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if nolunch==0, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp year_ok year_ga using apptab_b3_iv.xml, append excel title("Table B-3: Crowd-out ratio (ch. private given ch. public)")  ctitle("F/RP Lunch Eligible", "(2) + OK and GA specific linear trends")

qui xi: ivreg enrprepriv (enrprepub=post) i.statefip i.year [aw=nobs] if nolunch==1, cluster(clustervar)
outreg2 enrprepub using apptab_b3_iv.xml, append excel title("Table B-3: Crowd-out ratio (ch. private given ch. public)") ctitle("Not F/RP Lunch Eligible", "Baseline")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp i.statefip i.year [aw=nobs] if nolunch==1, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp using apptab_b3_iv.xml, append excel title("Table B-3: Crowd-out ratio (ch. private given ch. public)") ctitle("Not F/RP Lunch Eligible", "(1) + Demographic Controls and Unemployment")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if nolunch==1, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp year_ok year_ga using apptab_b3_iv.xml, append excel title("Table B-3: Crowd-out ratio (ch. private given ch. public)") ctitle("Not F/RP Lunch Eligible", "(2) + OK and GA specific linear trends")

* Erase text files
erase apptab_b3-enrpre.txt
erase apptab_b3-enrprepub.txt
erase apptab_b3-enrprepriv.txt
erase apptab_b3_iv.txt

cd ../..
