* apptab_b5.do

*******************************************
* October CPS
* DD estimates for preschool enrollment
* Comparison group: rest of U.S.
* Stratification variable: paternal college
*******************************************

use data\octcps\octcps1977_2011-st-dadcoll, clear
keep if age==4
gen clustervar=statefip


* convert dependent variables to percentages
gen enrprepriv=enrpre-enrprepub
foreach var in enrpre enrprepub enrprepriv {
	replace `var'=`var'*100
	}

cd outreg/appendixB

* DD estimates
foreach var in enrpre enrprepub enrprepriv {

	qui reg `var' post i.statefip i.year [aw=nobs] if dadcoll==0, cluster(clustervar)
	outreg2 post using apptab_b5-`var'.xml, replace excel title("Table B-5: `var'") ctitle("Father has HS or Less", "Baseline")

	qui reg `var' post nonwhite female unemp i.statefip i.year [aw=nobs] if dadcoll==0, cluster(clustervar)
	outreg2 post nonwhite female unemp using apptab_b5-`var'.xml, append excel title("Table B-5: `var'") ctitle("Father has HS or Less", "(1) + Demographic Controls and Unemployment")

	qui reg `var' post nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if dadcoll==0, cluster(clustervar)
	outreg2 post nonwhite female unemp year_ok year_ga using apptab_b5-`var'.xml, append excel title("Table B-5: `var'") ctitle("Father has HS or Less", "(2) + OK and GA specific linear trends")

	qui reg `var' post i.statefip i.year [aw=nobs] if dadcoll==1, cluster(clustervar)
	outreg2 post using apptab_b5-`var'.xml, append excel title("Table B-5: `var'") ctitle("Father has some college or more", "Baseline")

	qui reg `var' post nonwhite female unemp i.statefip i.year [aw=nobs] if dadcoll==1, cluster(clustervar)
	outreg2 post nonwhite female unemp using apptab_b5-`var'.xml, append excel title("Table B-5: `var'") ctitle("Father has some college or more", "(1) + Demographic Controls and Unemployment")

	qui reg `var' post nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if dadcoll==1, cluster(clustervar)
	outreg2 post nonwhite female unemp year_ok year_ga using apptab_b5-`var'.xml, append excel title("Table B-5: `var'") ctitle("Father has some college or more", "(2) + OK and GA specific linear trends")

}

* Crowd-out estimates (IV)

qui xi: ivreg enrprepriv (enrprepub=post) i.statefip i.year [aw=nobs] if dadcoll==0, cluster(clustervar)
outreg2 enrprepub using apptab_b5_iv.xml, replace excel title("Table B-5: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has HS or Less", "Baseline")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp i.statefip i.year [aw=nobs] if dadcoll==0, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp using apptab_b5_iv.xml, append excel title("Table B-5: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has HS or Less", "(1) + Demographic Controls and Unemployment")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if dadcoll==0, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp year_ok year_ga using apptab_b5_iv.xml, append excel title("Table B-5: Crowd-out ratio (ch. private given ch. public)")  ctitle("Father has HS or Less", "(2) + OK and GA specific linear trends")

qui xi: ivreg enrprepriv (enrprepub=post) i.statefip i.year [aw=nobs] if dadcoll==1, cluster(clustervar)
outreg2 enrprepub using apptab_b5_iv.xml, append excel title("Table B-5: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has some college or more", "Baseline")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp i.statefip i.year [aw=nobs] if dadcoll==1, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp using apptab_b5_iv.xml, append excel title("Table B-5: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has some college or more", "(1) + Demographic Controls and Unemployment")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if dadcoll==1, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp year_ok year_ga using apptab_b5_iv.xml, append excel title("Table B-5: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has some college or more", "(2) + OK and GA specific linear trends")

* Erase text files
erase apptab_b5-enrpre.txt
erase apptab_b5-enrprepub.txt
erase apptab_b5-enrprepriv.txt
erase apptab_b5_iv.txt

cd ../..
