* apptab_b6.do

*******************************************
* October CPS
* DD estimates for school enr and maternal emp
* Comparison group: rest of U.S.
* Stratification variable: paternal college
*******************************************

use data\octcps\octcps1977_2011-st-dadcoll, clear
gen clustervar=statefip

* convert dependent variables to percentages
gen enrpriv=enrolld-enrpub
foreach var in momwklw enrpub enrpriv {
	replace `var'=`var'*100
	}

gen age4=age==4
foreach var in post nonwhite female unemp {
	gen `var'xage4=`var'*age4
}

cd outreg/appendixB

* DD estimates	
foreach var in momwklw enrpub enrpriv {

	qui reg `var' post i.statefip i.year [aw=nobs] if dadcoll==0&age==4, cluster(clustervar)
	outreg2 post using apptab_b6-`var'.xml, replace excel title("Table B-6: `var'") ctitle("Father has HS or less", "4 yos", "DD")

	qui reg `var' post nonwhite female unemp i.statefip i.year [aw=nobs] if dadcoll==0&age==4, cluster(clustervar)
	outreg2 post nonwhite female unemp using apptab_b6-`var'.xml, append excel title("Table B-6: `var'") ctitle("Father has HS or less", "4 yos", "DD + Demographics and Unemployment")

	qui xi: reg `var' postxage4 post nonwhite* unemp* female* i.statefip*i.age4 i.year*i.age4 [aw=nobs] if dadcoll==0&age>=4, cluster(clustervar)
	outreg2 post* nonwhite* unemp* female* using apptab_b6-`var'.xml, append excel title("Table B-6: `var'") ctitle("Father has HS or less", "4+5 yos", "DDD + Demographics and Unemployment")

	qui reg `var' post i.statefip i.year [aw=nobs] if dadcoll==1&age==4, cluster(clustervar)
	outreg2 post using apptab_b6-`var'.xml, append excel title("Table B-6: `var'") ctitle("Father has some college or more", "4 yos", "DD")

	qui reg `var' post nonwhite female unemp i.statefip i.year [aw=nobs] if dadcoll==1&age==4, cluster(clustervar)
	outreg2 post nonwhite female unemp using apptab_b6-`var'.xml, append excel title("Table B-6: `var'") ctitle("Father has some college or more", "4 yos", "DD + Demographics and Unemployment")

	qui xi: reg `var' postxage4 post nonwhite* unemp* female* i.statefip*i.age4 i.year*i.age4 [aw=nobs] if dadcoll==1&age>=4, cluster(clustervar)
	outreg2 post* nonwhite* unemp* female* using apptab_b6-`var'.xml, append excel title("Table B-6: `var'") ctitle("Father has some college or more", "4+5 yos", "DDD + Demographics and Unemployment")

	}

* Crowd-out ratios

qui xi: ivreg enrpriv (enrpub=post) i.statefip i.year [aw=nobs] if dadcoll==0&age==4, cluster(clustervar)
outreg2 enrpub using apptab_b6_iv.xml, replace excel title("Table B-6: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has HS or less", "4 yos", "DD")

qui xi: ivreg enrpriv (enrpub=post) nonwhite female unemp i.statefip i.year [aw=nobs] if dadcoll==0&age==4, cluster(clustervar)
outreg2 enrpub nonwhite female unemp using apptab_b6_iv.xml, append excel title("Table B-6: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has HS or less", "4 yos", "DD + Demographics and Unemployment")

qui xi: ivreg enrpriv (enrpub=postxage4) post nonwhite* unemp* female* i.statefip*i.age4 i.year*i.age4 [aw=nobs] if dadcoll==0&age>=4, cluster(clustervar)
outreg2 enrpub nonwhite* unemp* female* using apptab_b6_iv.xml, append excel title("Table B-6: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has HS or less", "4+5 yos", "DDD + Demographics and Unemployment")

qui xi: ivreg enrpriv (enrpub=post) i.statefip i.year [aw=nobs] if dadcoll==1&age==4, cluster(clustervar)
outreg2 enrpub using apptab_b6_iv.xml, append excel title("Table B-6: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has some college or more", "4 yos", "DD")

qui xi: ivreg enrpriv (enrpub=post) nonwhite female unemp i.statefip i.year [aw=nobs] if dadcoll==1&age==4, cluster(clustervar)
outreg2 enrpub nonwhite female unemp using apptab_b6_iv.xml, append excel title("Table B-6: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has some college or more", "4 yos", "DD + Demographics and Unemployment")

qui xi: ivreg enrpriv (enrpub=postxage4) post nonwhite* unemp* female* i.statefip*i.age4 i.year*i.age4 [aw=nobs] if dadcoll==1&age>=4, cluster(clustervar)
outreg2 enrpub nonwhite* unemp* female* using apptab_b6_iv.xml, append excel title("Table B-6: Crowd-out ratio (ch. private given ch. public)") ctitle("Father has some college or more", "4+5 yos", "DDD + Demographics and Unemployment")

* erase text files
erase apptab_b6-momwklw.txt
erase apptab_b6-enrpub.txt
erase apptab_b6-enrpriv.txt
erase apptab_b6_iv.txt

cd ../..
