* apptab_c1.do

*******************************************
* October CPS
* DD estimates for preschool enrollment 
* Comparison group: other states in southern Census region 
* Stratification variable: maternal college
*******************************************

use data\octcps\octcps1977_2011-st-momcoll, clear
keep if age==4
gen clustervar=statefip
keep if statefip==1|statefip==5|statefip==10|statefip==11|statefip==12|statefip==13|statefip==21|statefip==22|statefip==24|statefip==28|statefip==37|statefip==40|statefip==45|statefip==47|statefip==48|statefip==51|statefip==54

* convert dependent variables to percentages
gen enrprepriv=enrpre-enrprepub
foreach var in enrpre enrprepub enrprepriv {
	replace `var'=`var'*100
	}

cd outreg/appendixC

* DD estimates
foreach var in enrpre enrprepub enrprepriv {

	qui reg `var' post i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
	outreg2 post using apptab_c1-`var'.xml, replace excel title("Table C-1: `var'") ctitle("Mother has HS or Less", "Baseline")

	qui reg `var' post nonwhite female unemp i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
	outreg2 post nonwhite female unemp using apptab_c1-`var'.xml, append excel title("Table C-1: `var'") ctitle("Mother has HS or Less", "(1) + Demographic Controls and Unemployment")

	qui reg `var' post nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
	outreg2 post nonwhite female unemp year_ok year_ga using apptab_c1-`var'.xml, append excel title("Table C-1: `var'") ctitle("Mother has HS or Less", "(2) + OK and GA specific linear trends")

	qui reg `var' post i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
	outreg2 post using apptab_c1-`var'.xml, append excel title("Table C-1: `var'") ctitle("Mother has some college or more", "Baseline")

	qui reg `var' post nonwhite female unemp i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
	outreg2 post nonwhite female unemp using apptab_c1-`var'.xml, append excel title("Table C-1: `var'") ctitle("Mother has some college or more", "(1) + Demographic Controls and Unemployment")

	qui reg `var' post nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
	outreg2 post nonwhite female unemp year_ok year_ga using apptab_c1-`var'.xml, append excel title("Table C-1: `var'") ctitle("Mother has some college or more", "(2) + OK and GA specific linear trends")

}

* Crowd-out estimates (IV)

qui xi: ivreg enrprepriv (enrprepub=post) i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
outreg2 enrprepub using apptab_c1_iv.xml, replace excel title("Table C-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has HS or Less", "Baseline")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp using apptab_c1_iv.xml, append excel title("Table C-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has HS or Less", "(1) + Demographic Controls and Unemployment")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp year_ok year_ga using apptab_c1_iv.xml, append excel title("Table C-1: Crowd-out ratio (ch. private given ch. public)")  ctitle("Mother has HS or Less", "(2) + OK and GA specific linear trends")

qui xi: ivreg enrprepriv (enrprepub=post) i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
outreg2 enrprepub using apptab_c1_iv.xml, append excel title("Table C-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has some college or more", "Baseline")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp using apptab_c1_iv.xml, append excel title("Table C-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has some college or more", "(1) + Demographic Controls and Unemployment")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp year_ok year_ga using apptab_c1_iv.xml, append excel title("Table C-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has some college or more", "(2) + OK and GA specific linear trends")

* Erase text files
erase apptab_c1-enrpre.txt
erase apptab_c1-enrprepub.txt
erase apptab_c1-enrprepriv.txt
erase apptab_c1_iv.txt

cd ../..
