* apptab_d1.do

*******************************************
* October CPS
* DD estimates for preschool enrollment 
* Comparison group: rest of U.S.
* Stratification variable: maternal college
* Unweighted
*******************************************

use data\octcps\octcps1977_2011-st-momcoll, clear
keep if age==4
gen clustervar=statefip

* convert dependent variables to percentages
gen enrprepriv=enrpre-enrprepub
foreach var in enrpre enrprepub enrprepriv {
	replace `var'=`var'*100
	}

cd outreg/appendixD

* DD estimates
foreach var in enrpre enrprepub enrprepriv {

	qui reg `var' post i.statefip i.year if momcoll==0, cluster(clustervar)
	outreg2 post using apptab_d1-`var'.xml, replace excel title("Table D-1: `var'") ctitle("Mother has HS or less", "Baseline")

	qui reg `var' post nonwhite female unemp i.statefip i.year if momcoll==0, cluster(clustervar)
	outreg2 post nonwhite female unemp using apptab_d1-`var'.xml, append excel title("Table D-1: `var'") ctitle("Mother has HS or less", "(1) + Demographic Controls and Unemployment")

	qui reg `var' post nonwhite female unemp year_ok year_ga i.statefip i.year if momcoll==0, cluster(clustervar)
	outreg2 post nonwhite female unemp year_ok year_ga using apptab_d1-`var'.xml, append excel title("Table D-1: `var'") ctitle("Mother has HS or less", "(2) + OK and GA specific linear trends")

	qui reg `var' post i.statefip i.year if momcoll==1, cluster(clustervar)
	outreg2 post using apptab_d1-`var'.xml, append excel title("Table D-1: `var'") ctitle("Mother has some college or more", "Baseline")

	qui reg `var' post nonwhite female unemp i.statefip i.year if momcoll==1, cluster(clustervar)
	outreg2 post nonwhite female unemp using apptab_d1-`var'.xml, append excel title("Table D-1: `var'") ctitle("Mother has some college or more", "(1) + Demographic Controls and Unemployment")

	qui reg `var' post nonwhite female unemp year_ok year_ga i.statefip i.year if momcoll==1, cluster(clustervar)
	outreg2 post nonwhite female unemp year_ok year_ga using apptab_d1-`var'.xml, append excel title("Table D-1: `var'") ctitle("Mother has some college or more", "(2) + OK and GA specific linear trends")

}

* Crowd-out estimates (IV)

qui xi: ivreg enrprepriv (enrprepub=post) i.statefip i.year if momcoll==0, cluster(clustervar)
outreg2 enrprepub using apptab_d1_iv.xml, replace excel title("Table D-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has HS or less", "Baseline")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp i.statefip i.year if momcoll==0, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp using apptab_d1_iv.xml, append excel title("Table D-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has HS or less", "(1) + Demographic Controls and Unemployment")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp year_ok year_ga i.statefip i.year if momcoll==0, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp year_ok year_ga using apptab_d1_iv.xml, append excel title("Table D-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has HS or less", "(2) + OK and GA specific linear trends")

qui xi: ivreg enrprepriv (enrprepub=post) i.statefip i.year if momcoll==1, cluster(clustervar)
outreg2 enrprepub using apptab_d1_iv.xml, append excel title("Table D-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has some college or more", "Baseline")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp i.statefip i.year if momcoll==1, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp using apptab_d1_iv.xml, append excel title("Table D-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has some college or more", "(1) + Demographic Controls and Unemployment")

qui xi: ivreg enrprepriv (enrprepub=post) nonwhite female unemp year_ok year_ga i.statefip i.year if momcoll==1, cluster(clustervar)
outreg2 enrprepub nonwhite female unemp year_ok year_ga using apptab_d1_iv.xml, append excel title("Table D-1: Crowd-out ratio (ch. private given ch. public)") ctitle("Mother has some college or more", "(2) + OK and GA specific linear trends")

* Erase text files
erase apptab_d1-enrpre.txt
erase apptab_d1-enrprepub.txt
erase apptab_d1-enrprepriv.txt
erase apptab_d1_iv.txt

cd ../..
