* apptab_g1-spec1.do
* Conley-Taber confidence intervals 
* Specification 1 of Table 2

global not40 "ga"
global not13 "ok"

set more off

set logtype text
cap log close
log using outreg\appendixG\apptab_g1-spec1, replace

dis as text "Specification 1: Baseline DD"

log close

foreach var in enrpre enrprepub enrprepriv {
	foreach m in 0 1 {
		foreach s in 13 40 {	
			use data\octcps\octcps1977_2011-st-momcoll, clear
			keep if age==4&momcoll==`m'
			drop if statefip==`s'
			gen clustervar=statefip

			gen enrprepriv=enrpre-enrprepub
			replace enrprepriv=enrprepriv*100
			replace enrprepub=enrprepub*100
			replace enrpre=enrpre*100

			sum year 
			g yrmin=r(min)
			g yrmax=r(max)

			xi: reg `var' post i.year i.state [aw=nobs], cluster(clustervar)
			outreg2 post using outreg\appendixG\apptab_g1-${not`s'}-momcoll`m'-`var'.xml, excel replace noaster
			/* Create state and year dummies*/
			g yr=yrmin
			quietly {
				while yr<=yrmax {
				local k=yr
					g byte Dyear_`k'=year==`k' 
					replace yr=yr+1
					}		
			}
	
			levelsof statefip , local(states)
			quietly {
				foreach st in `states' {
					g byte Dstate_`st'=state==`st' 
				}
			}
	
		* Now regress the coefficients (beta) obtained from the previous regression 
		*on state and year dummies and post variable
		reg `var' post Dstat* Dyear* [aw=nobs], noc

		* Predict residuals from regression 
		predict eta, res 
		replace eta=eta+_b[post]*post
		drop D*

		* Create d tilde variable (weighted)
		bysort year: egen djt${not`s'}=mean(post) if ${not`s'}==1
		bysort year: egen djt=sum(djt${not`s'}) 
		*bysort state: egen meandjt=mean(djt)
		bysort state: egen meandjt_num=sum(djt*nobs)
		bysort state: egen meandjt_denom=sum(nobs)
		bysort state: gen meandjt=meandjt_num/meandjt_denom
		g dtil=djt-meandjt

		* Obtain difference in differences coefficient
		reg eta dtil [aw=nobs] if ${not`s'}==1,noc
		matrix alpha=e(b)
	
		* Simulations
		quietly {
			foreach st in `states' {
				capture {
				reg eta dtil [aw=nobs] if state==`st'&${not`s'}!=1, noc
				matrix alpha=alpha\e(b)
			}
			}
		} 
		matrix asim=alpha[2...,1]
		matrix alpha=alpha[1,1]

		* Confidence intervals
		svmat alpha 
		svmat asim

		sum alpha
		gen alpha=r(mean)
		g ci=alpha-asim

		* form confidence intervals
		local numst=50
		local i025=floor(0.025*(`numst'-1))
		local i975=ceil(0.975*(`numst'-1))
		local i05=floor(0.050*(`numst'-1))
		local i95=ceil(0.950*(`numst'-1))

		log using outreg\appendixG\apptab_g1-spec1, append		
		dis as text "var=`var', momcoll==`m', state=${not`s'}"
		quietly sum alpha
		display as text "Difference in Differences coefficient=" as result _newline(2) r(mean)

		sort asim
		quietly sum ci if _n==`i025'|_n==`i975'
		display as text "95% Confidence interval=" as result _newline(2) r(min) _col(15) r(max)
		quietly sum ci if _n==`i05'|_n==`i95' 
		display as text "90% Confidence interval=" as result _newline(2) r(min) _col(15) r(max)

		log close
		}
	}
}
