* apptab_g1-spec3-pooled.do
* Conley-Taber confidence intervals 
* Specification 3 of Table 2
* Unweighted case

global not40 "ga"
global not13 "ok"

set more off

set logtype text
cap log close
log using outreg\appendixG\apptab_g1-spec3-pooled, replace

dis as text "Specification 3: Add OK and GA specific trends"

log close

foreach var in enrpre enrprepub enrprepriv {
	foreach m in 0 1  {
		use data\octcps\octcps1977_2011-st-momcoll, clear
		keep if age==4&momcoll==`m'
		gen clustervar=statefip

		gen enrprepriv=enrpre-enrprepub
		replace enrprepriv=enrprepriv*100
		replace enrprepub=enrprepub*100
		replace enrpre=enrpre*100

		sum year 
		g yrmin=r(min)
		g yrmax=r(max)

		xi: reg `var' post nonwhite female unemp year_ok year_ga i.year i.state, cluster(clustervar)
		outreg2 post using outreg\appendixG\apptab_g1-momcoll`m'-`var'.xml, excel append noaster
		/* Create state and year dummies*/
		g yr=yrmin
		quietly {
			while yr<=yrmax {
			local k=yr
				g byte Dyear_`k'=year==`k' 
				replace yr=yr+1
				}		
		}
	
		levelsof statefip , local(states)
		quietly {
			foreach st in `states' {
				g byte Dstate_`st'=state==`st' 
			}
		}
	
		* Now regress the coefficients (beta) obtained from the previous regression 
		*on state and year dummies and post variable
		reg `var' post nonwhite female unemp year_ok year_ga Dstat* Dyear*, noc

		* Predict residuals from regression 
		predict eta, res 
		replace eta=eta+_b[post]*post
		gen alpha=_b[post]
		drop D*

		* Create d tilde variable 
		bysort year: egen djtga=mean(post) if ga==1
		bysort year: egen djtok=mean(post) if ok==1
		bysort year: egen d1t=sum(djtga) 
		bysort year: egen d2t=sum(djtok) 
		bysort state: egen meand1t=mean(d1t)
		bysort state: egen meand2t=mean(d2t)

		g double dtil1=(d1t-meand1t)
		g double dtil2=(d2t-meand2t)
		g double dtil1_2=(d1t-meand1t)^2
		g double dtil2_2=(d2t-meand2t)^2
		bysort state: egen double sumt_dtil1=sum(dtil1*eta)
		bysort state: egen double sumt_dtil2=sum(dtil2*eta)
		bysort state: egen double sumt_dtil1_2=sum(dtil1_2)
		bysort state: egen double sumt_dtil2_2=sum(dtil2_2)
		g double asim=(sumt_dtil1+sumt_dtil2)/(sumt_dtil1_2+sumt_dtil2_2)	
*		g double x=asim if ga==1
*		egen double alpha=sum(x), by(year)
		
		collapse (mean) asim alpha, by(state)
				
		gen ci=alpha-asim
		local numst=51
		local i025=floor(0.025*(`numst'-2))
		local i975=ceil(0.975*(`numst'-2))
		local i05=floor(0.050*(`numst'-2))
		local i95=ceil(0.950*(`numst'-2))
		
		log using outreg\appendixG\apptab_g1-spec3-pooled, append		
		dis as text "var=`var', momcoll==`m'"

		quietly sum alpha if state==13
		display as text "Check: Difference in Differences coefficient (based on GA)=" as result _newline(2) r(mean)
		quietly sum alpha if state==40
		display as text "Check: Difference in Differences coefficient (based on OK)=" as result _newline(2) r(mean)

		drop if state==13|state==40
		sort ci 
		quietly sum ci if _n==`i05'|_n==`i95'
		display as text "90% Confidence interval=" as result _newline(2) r(min) _col(15) r(max)
		quietly sum ci if _n==`i025'|_n==`i975'
		display as text "95% Confidence interval=" as result _newline(2) r(min) _col(15) r(max)
		log close

		erase outreg\appendixG\apptab_g1-momcoll`m'-`var'.txt

	}
}
