* conley-taber.do
* 10.25.13

* My first attempt at adapting the Conley-Taber code to our application.
* Working from C-T ga_ew.do
* Key differences: (1) they are working with statexyear fixed effects (regression-adjusted)
* from individual level data, while we are working with data already collapsed to the 
* state-year level.  (2) We have 2 treatment states instead of just one.  The multiple-
* treatment state code is considerably more complicated, however, so I'm going to try this
* first.

clear
clear matrix
set more off
set matsize 800
set mem 200m

use data\octcps\octcps1977_2011-st-momcoll, clear
keep if age==4&momcoll==0
drop if statefip==13
gen clustervar=statefip

gen enrprepriv=enrpre-enrprepub
foreach var in enrpre enrprepub enrprepriv {
	replace `var'=`var'*100
	}

sum year 
g yrmin=r(min)
g yrmax=r(max)

xi: reg enrprepub post i.year i.state [aw=nobs], cluster(clustervar)
/* Create state and year dummies*/
g yr=yrmin
quietly {
	while yr<=yrmax {
	local k=yr
		g byte Dyear_`k'=year==`k' 
		replace yr=yr+1
		}		
}

levelsof statefip , local(states)
quietly {
	foreach st in `states' {
		g byte Dstate_`st'=state==`st' 
	}
}

* Now regress the coefficients (beta) obtained from the previous regression 
*on state and year dummies and post variable
reg enrprepub post Dstat* Dyear* [aw=nobs], noc

* Predict residuals from regression 
predict eta, res 
replace eta=eta+_b[post]*post
drop D*

* Create d tilde variable (weighted)
bysort year: egen djtok=mean(post) if ok==1
bysort year: egen djt=sum(djtok) 
*bysort state: egen meandjt=mean(djt)
bysort state: egen meandjt_num=sum(djt*nobs)
bysort state: egen meandjt_denom=sum(nobs)
bysort state: gen meandjt=meandjt_num/meandjt_denom
g dtil=djt-meandjt

* Obtain difference in differences coefficient
reg eta dtil [aw=nobs] if ok==1,noc
matrix alpha=e(b)
	
* Simulations
quietly {
	foreach st in `states' {
		capture {
		reg eta dtil [aw=nobs] if state==`st'&ok!=1, noc
		matrix alpha=alpha\e(b)
	}
	}
} 
matrix asim=alpha[2...,1]
matrix alpha=alpha[1,1]

* Confidence intervals
svmat alpha 
svmat asim

sum alpha
gen alpha=r(mean)
g ci=alpha-asim

* form confidence intervals
local numst=50
local i025=floor(0.025*(`numst'-1))
local i975=ceil(0.975*(`numst'-1))
local i05=floor(0.050*(`numst'-1))
local i95=ceil(0.950*(`numst'-1))

quietly sum alpha
display as text "Difference in Differences coefficient=" as result _newline(2) r(mean)

sort asim
quietly sum ci if _n==`i025'|_n==`i975'
display as text "95% Confidence interval=" as result _newline(2) r(min) _col(15) r(max)
quietly sum ci if _n==`i05'|_n==`i95' 
display as text "90% Confidence interval=" as result _newline(2) r(min) _col(15) r(max)
local i025=floor(0.025*(`numst'-1))
local i975=ceil(0.975*(`numst'-1))
local i05=floor(0.050*(`numst'-1))
local i95=ceil(0.950*(`numst'-1))

