* apptab_f1.do

*******************************************
* October CPS 
* DD estimates for preschool enrollment
* Comparison group: rest of U.S.
* Stratification variable: maternal college
* Separate treatment effects for GA and OK
*******************************************

use data\octcps\octcps1977_2011-st-momcoll, clear
keep if age==4
gen clustervar=statefip

* convert dependent variables to percentages

gen enrprepriv=enrpre-enrprepub

foreach var in enrpre enrprepub enrprepriv {
	replace `var'=`var'*100
	}

cd outreg/appendixF

* DD estimates
foreach var in enrpre enrprepub enrprepriv {

	qui reg `var' post post_ga i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
	local diff=_b[post_ga]
	local tstat=abs(_b[post_ga]/_se[post_ga])
	qui reg `var' post_ok post_ga i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
	outreg2 post_ok post_ga using apptab_f1-`var'.xml, replace excel noaster title("Table F-1: `var'") ctitle("Mother has HS or less", "Baseline") addstat(GA-OK diff, `diff', t-stat on diff, `tstat')

	qui reg `var' post post_ga nonwhite female unemp i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
	local diff=_b[post_ga]
	local tstat=abs(_b[post_ga]/_se[post_ga])
	qui reg `var' post_ok post_ga nonwhite female unemp i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
	outreg2 post_ok post_ga nonwhite female unemp using apptab_f1-`var'.xml, append excel noaster title("Table F-1: `var'") ctitle("Mother has HS or less", "(1) + Demographic Controls and Unemployment") addstat(GA-OK diff, `diff', t-stat on diff, `tstat')

	qui reg `var' post post_ga nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
	local diff=_b[post_ga]
	local tstat=abs(_b[post_ga]/_se[post_ga])
	qui reg `var' post_ok post_ga nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if momcoll==0, cluster(clustervar)
	outreg2 post_ok post_ga nonwhite female unemp year_ok year_ga using apptab_f1-`var'.xml, append excel noaster title("Table F-1: `var'") ctitle("Mother has HS or less", "(2) + OK and GA specific linear trends") addstat(GA-OK diff, `diff', t-stat on diff, `tstat')

	qui reg `var' post post_ga i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
	local diff=_b[post_ga]
	local tstat=abs(_b[post_ga]/_se[post_ga])
	qui reg `var' post_ok post_ga i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
	outreg2 post_ok post_ga using apptab_f1-`var'.xml, append excel noaster title("Table F-1: `var'") ctitle("Mother has some college or more", "Baseline") addstat(t-stat on diff, `tstat')

	qui reg `var' post post_ga nonwhite female unemp i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
	local diff=_b[post_ga]
	local tstat=abs(_b[post_ga]/_se[post_ga])
	qui reg `var' post_ok post_ga nonwhite female unemp i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
	outreg2 post_ok post_ga nonwhite female unemp using apptab_f1-`var'.xml, append excel noaster title("Table F-1: `var'") ctitle("Mother has some college or more", "(1) + Demographic Controls and Unemployment") addstat(GA-OK diff, `diff', t-stat on diff, `tstat')

	qui reg `var' post post_ga nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
	local diff=_b[post_ga]
	local tstat=abs(_b[post_ga]/_se[post_ga])
	qui reg `var' post_ok post_ga nonwhite female unemp year_ok year_ga i.statefip i.year [aw=nobs] if momcoll==1, cluster(clustervar)
	outreg2 post_ok post_ga nonwhite female unemp year_ok year_ga using apptab_f1-`var'.xml, append excel noaster title("Table F-1: `var'") ctitle("Mother has some college or more", "(2) + OK and GA specific linear trends") addstat(GA-OK diff, `diff', t-stat on diff, `tstat')

}

* Erase text files
erase apptab_f1-enrpre.txt
erase apptab_f1-enrprepub.txt
erase apptab_f1-enrprepriv.txt

cd ../..
