* octcps_collapse.do
* 10.24.13

* Collapses the October CPS microdata to national averages (all years)
* and to state averages (1977-2011 only), overall and by various measures
* of SES: maternal education, paternal education, and imputed free/reduced
* price lunch eligbility

cd data\octcps

********************************
* NATIONAL AVERAGES
********************************

* OVERALL: means
use octcps1968_2011, clear
foreach g in mom dad {
	gen `g'coll=`g'educ==3|`g'educ==4
	replace `g'coll=. if `g'educ==.
	}
sum momcoll dadcoll
tab momcoll dadcoll
gen anycoll=momcoll==1|dadcoll==1
replace anycoll=. if momcoll==.&dadcoll==.
gen black=racerec==2
gen nonwhite=racerec>=2
gen female=sex==2
drop momeduc dadeduc
save tmp, replace
collapse (mean) enr* momcoll dadcoll lunch momwklw black nonwhite female [pw=wtfinl], by(age year)
sort age year
save octcps1968_2011-nat, replace
* OVERALL: cell size (based on enrolld)
use tmp, clear
collapse (count) nobs=enrolld, by(age year)
sort age year
merge age year using octcps1968_2011-nat, unique
tab _merge
drop _merge
save octcps1968_2011-nat, replace

* BY MATERNAL EDUCATION: means
use tmp, clear
collapse (mean) enr* lunch dadcoll anycoll momwklw black nonwhite female [pw=wtfinl], by(age year momcoll)
sort age year momcoll
save octcps1968_2011-nat-momcoll, replace
* BY MATERNAL EDUCATION: cell size
use tmp, clear
collapse (count) nobs=enrolld, by(age year momcoll)
sort age year momcoll
merge age year momcoll using octcps1968_2011-nat-momcoll, unique
tab _merge
drop _merge
drop if momcoll==.
save octcps1968_2011-nat-momcoll, replace

********************************
* STATE AVERAGES
********************************

* OVERALL: means
use octcps1968_2011, clear
foreach g in mom dad {
	gen `g'coll=`g'educ==3|`g'educ==4
	replace `g'coll=. if `g'educ==.
	}
sum momcoll dadcoll
tab momcoll dadcoll
gen anycoll=momcoll==1|dadcoll==1
replace anycoll=. if momcoll==.&dadcoll==.
gen black=racerec==2
gen nonwhite=racerec>=2
gen female=sex==2
drop momeduc dadeduc
drop if year<1977
gen nomissdad=dadcoll~=.
gen nomissmom=momcoll~=.
gen nomisslunch=lunch~=.
save tmp, replace
collapse (mean) enr* momcoll dadcoll lunch momwklw black nonwhite female nomiss* [pw=wtfinl], by(age year statefip)
sort age year statefip
save octcps1977_2011-st, replace
* OVERALL: cell size (based on enrolld)
use tmp, clear
collapse (count) nobs=enrolld, by(age year statefip)
sort age year statefip
merge age year statefip using octcps1977_2011-st, unique
tab _merge
drop _merge
save octcps1977_2011-st, replace

* BY MATERNAL EDUCATION: means
use tmp, clear
collapse (mean) enr* lunch dadcoll anycoll momwklw black nonwhite female [pw=wtfinl], by(age year statefip momcoll)
sort age year statefip momcoll
save octcps1977_2011-st-momcoll, replace
* BY MATERNAL EDUCATION: cell size
use tmp, clear
collapse (count) nobs=enrolld, by(age year statefip momcoll)
sort age year statefip momcoll
merge age year statefip momcoll using octcps1977_2011-st-momcoll, unique
tab _merge
drop _merge
drop if momcoll==.
save octcps1977_2011-st-momcoll, replace

* BY PATERNAL EDUCATION: means
use tmp, clear
collapse (mean) enr* lunch momcoll anycoll momwklw black nonwhite female [pw=wtfinl], by(age year statefip dadcoll)
sort age year statefip dadcoll
save octcps1977_2011-st-dadcoll, replace
* BY PATERNAL EDUCATION: cell size
use tmp, clear
collapse (count) nobs=enrolld, by(age year statefip dadcoll)
sort age year statefip dadcoll
merge age year statefip dadcoll using octcps1977_2011-st-dadcoll, unique
tab _merge
drop _merge
drop if dadcoll==.
save octcps1977_2011-st-dadcoll, replace

* BY FREE LUNCH STATUS
use tmp, clear
collapse (mean) enr* momcoll dadcoll anycoll momwklw black nonwhite female [pw=wtfinl], by(age year statefip lunch)
sort age year statefip lunch
save octcps1977_2011-st-lunch, replace
* BY PATERNAL EDUCATION: cell size
use tmp, clear
collapse (count) nobs=enrolld, by(age year statefip lunch)
sort age year statefip lunch
merge age year statefip lunch using octcps1977_2011-st-lunch, unique
tab _merge
drop _merge
drop if lunch==.
save octcps1977_2011-st-lunch, replace

********************************
* MERGE STATE UNEMPLOYMENT RATE
* CREATE TREATMENT VARIABLES
********************************

use octcps1977_2011-st, clear
sort statefip year
merge statefip year using ..\labor_force\annual_lf_data, uniqusing keep(a_urate_st)
ren a_urate_st unemp
label var unemp "state unemployment rate" 
tab _merge
drop if _merge==2
drop _merge

gen ok=statefip==40
label var ok "=1 if Oklahoma"
gen ga=statefip==13
label var ga "=1 if Georgia"
gen post=0
replace post=1 if (year>=1998)&ok
replace post=1 if (year>=1995)&ga
label var post "=1 if after high-quality universal preschool"
gen year_ok=year*ok
gen year_ga=year*ga
label var year_ok "ok (dummy) x year (linear)"
label var year_ok "ga (dummy) x year (linear)"
gen normyear=.
replace normyear=year-1998 if ok
replace normyear=year-1995 if ga
label var normyear "year - 1st year of high-quality universal preschool"

gen normyrgrp=.
replace normyrgrp=-11 if normyear<=-10
replace normyrgrp=-8 if normyear>=-9&normyear<=-7
replace normyrgrp=-5 if normyear>=-6&normyear<=-4
replace normyrgrp=-2 if normyear>=-3&normyear<=-1
replace normyrgrp=1 if normyear>=0&normyear<=2
replace normyrgrp=4 if normyear>=3&normyear<=5
replace normyrgrp=7 if normyear>=6&normyear<=8
replace normyrgrp=10 if normyear>=9&normyear<=11
replace normyrgrp=13 if normyear>=12
replace normyrgrp=. if normyear==.
label var normyrgrp "midpoint of 3-year interval for normyear"

foreach yr in 11 8 5 {
	gen normyrl`yr'=normyrgrp==-`yr'
	label var normyrl`yr' "=1 if normyrgrp=-`yr'"
}

foreach yr in 1 4 7 10 13 {
	gen normyrp`yr'=normyrgrp==`yr'
	label var normyrp`yr' "=1 if normyrgrp=`yr'"
}

gen post_ga=post*ga
label var post_ga "post (dummy) x ga (dummy)"

save, replace

foreach g in momcoll dadcoll lunch {

	use octcps1977_2011-st-`g', clear
	sort statefip year
	merge statefip year using ..\labor_force\annual_lf_data, uniqusing keep(a_urate_st)
	ren a_urate_st unemp
	label var unemp "state unemployment rate" 
	tab _merge
	drop if _merge==2
	drop _merge

	gen ok=statefip==40
	label var ok "=1 if Oklahoma"
	gen ga=statefip==13
	label var ga "=1 if Georgia"
	gen post=0
	replace post=1 if (year>=1998)&ok
	replace post=1 if (year>=1995)&ga
	label var post "=1 if after high-quality universal preschool"
	gen year_ok=year*ok
	gen year_ga=year*ga
	label var year_ok "ok (dummy) x year (linear)"
	label var year_ga "ga (dummy) x year (linear)"
	gen normyear=.
	replace normyear=year-1998 if ok
	replace normyear=year-1995 if ga
	label var normyear "year - 1st year of high-quality universal preschool"
		
	gen normyrgrp=.
	replace normyrgrp=-11 if normyear<=-10
	replace normyrgrp=-8 if normyear>=-9&normyear<=-7
	replace normyrgrp=-5 if normyear>=-6&normyear<=-4
	replace normyrgrp=-2 if normyear>=-3&normyear<=-1
	replace normyrgrp=1 if normyear>=0&normyear<=2
	replace normyrgrp=4 if normyear>=3&normyear<=5
	replace normyrgrp=7 if normyear>=6&normyear<=8
	replace normyrgrp=10 if normyear>=9&normyear<=11
	replace normyrgrp=13 if normyear>=12
	replace normyrgrp=. if normyear==.
	label var normyrgrp "midpoint of 3-year interval for normyear"
	
	foreach yr in 11 8 5 {
		gen normyrl`yr'=normyrgrp==-`yr'
		label var normyrl`yr' "=1 if normyrgrp=-`yr'"
	}
	
	foreach yr in 1 4 7 10 13 {
		gen normyrp`yr'=normyrgrp==`yr'
		label var normyrp`yr' "=1 if normyrgrp=`yr'"
	}

	
	gen post_ga=post*ga
	label var post_ga "post (dummy) x ga (dummy)"
	
	gen post_ok=post*ok
	label var post_ok "post (dummy) x ok (dummy)"

	foreach yr in 11 8 5 {
		gen normyrl`yr'_ga=normyrl`yr'*ga
		label var normyrl`yr'_ga "=1 if normyrgrp=-`yr' and state=ga"
	}
	
	foreach yr in 1 4 7 10 13 {
		gen normyrp`yr'_ga=normyrp`yr'*ga
		label var normyrp`yr' "=1 if normyrgrp=`yr' and state=ga"
	}

	foreach yr in 11 8 5 {
		gen normyrl`yr'_ok=normyrl`yr'*ok
		label var normyrl`yr'_ok "=1 if normyrgrp=-`yr' and state=ok"
	}
	
	foreach yr in 1 4 7 10 13 {
		gen normyrp`yr'_ok=normyrp`yr'*ok
		label var normyrp`yr' "=1 if normyrgrp=`yr' snd state=ok"
	}

	save, replace
}

erase tmp.dta

cd ..\..


